@@ -96,6 +96,11 @@ LockStruct  LockProcs[] =
 	{"bat",
 	 100000, -8, 1, 0, 64, 1.0, "",
 	 "Shows bouncing flying bats", 0, NULL, NULL},
+#ifdef USE_GL
+	{"bevel",
+	 100000, -30, 5, 1, 64, 1.0, "",
+	 "Shows an auto-solving Bevel or Helicopter Cube", 0, NULL, "#ifdef USE_GL"},
+#endif
 	{"blot",
 	 200000, 6, 30, 1, 64, 0.3, "",
 	 "Shows Rorschach's ink blot test", 0, NULL, NULL},
@@ -156,6 +161,11 @@ LockStruct  LockProcs[] =
 	{"dilemma",
 	 200000, -2, 1000, 0, 64, 1.0, "",
 	 "Shows Lloyd's Prisoner's Dilemma simulation", 0, NULL, NULL},
+#ifdef USE_GL
+	{"dino",
+	 100000, -30, 5, 1, 64, 1.0, "",
+	 "Shows an auto-solving Dinosaur Cube", 0, NULL, "#ifdef USE_GL"},
+#endif
 	{"discrete",
 	 1000, 4096, 2500, 1, 64, 1.0, "",
 	 "Shows various discrete maps", 0, NULL, NULL},
@@ -305,6 +315,9 @@ LockStruct  LockProcs[] =
 	{"moebius",
 	 30000, 1, 1, 1, 64, 1.0, "",
 	 "Shows Moebius Strip II, an Escher-like GL scene with ants", 0, NULL, "#ifdef USE_GL"},
+	{"mball",
+	 100000, -30, 5, -6, 64, 1.0, "",
+	 "Shows an auto-solving Masterball puzzle", 0, NULL, "#ifdef USE_GL"},
 	{(char *) "molecule",
 	 50000, 1, 20, 1, 64, 1.0, "",
 	 "Draws molecules", 0, NULL, "#ifdef USE_GL"},
@@ -326,6 +339,11 @@ LockStruct  LockProcs[] =
 	{"nose",
 	 100000, 1, 1, 1, 64, 1.0, "",
 	 "Shows a man with a big nose runs around spewing out messages", 0, NULL, NULL},
+#ifdef USE_GL
+	{"oct",
+	 100000, -30, 5, -5, 64, 1.0, "",
+	 "Shows an auto-solving octahedron puzzle", 0, NULL, "#ifdef USE_GL"},
+#endif
 	{"pacman",
 	 10000, 10, 1, 0, 64, 1.0, "",
 	 "Shows Pacman(tm)", 0, NULL, NULL},
@@ -349,6 +367,11 @@ LockStruct  LockProcs[] =
 	{"puzzle",
 	 10000, 250, 1, 1, 64, 1.0, "",
 	 "Shows a puzzle being scrambled and then solved", 0, NULL, NULL},
+#ifdef USE_GL
+	{"pyraminx",
+	 100000, -30, 5, -5, 64, 1.0, "",
+	 "Shows an auto-solving Pyraminx puzzle", 0, NULL, "#ifdef USE_GL"},
+#endif
 	{"pyro",
 	 15000, 100, 1, -3, 64, 1.0, "",
 	 "Shows fireworks", 0, NULL, NULL},
@@ -502,10 +525,8 @@ LockStruct  LockProcs[] =
 	{"xjack",
 	 50000, 1, 1, 1, 64, 1.0, "",
 	 "Shows Jack having one of those days", 0, NULL, NULL},
-
 /* SPECIAL MODES */
 	{"blank",
 	 3000000, 1, 1, 1, 64, 1.0, "",
 	 "Shows nothing but a black screen", 0, NULL, NULL}
-
 };
