@@ -523,7 +523,7 @@ openfilesel filename
 set f [ open $filename r ]
 while { ! [eof $f ] } {
 	gets $f line
-       	switch -regexp $line {
+	switch -regexp $line {
 	{^XLock\.[a-zA-Z]+:} {
 		if { [ regexp -nocase {\: $} tyty ]} {
 		}
@@ -658,6 +658,7 @@ atlantis\
 atunnels\
 ball\
 bat\
+bevel\
 blot\
 bouboule\
 bounce\
@@ -676,6 +677,7 @@ decay\
 deco\
 demon\
 dilemma\
+dino\
 discrete\
 dragon\
 drift\
@@ -722,12 +724,14 @@ matrix\
 maze\
 maze3d\
 moebius\
+mball\
 molecule\
 morph3d\
 mountain\
 munch\
 noof\
 nose\
+oct\
 pacman\
 penrose\
 petal\
@@ -735,6 +739,7 @@ petri\
 pipes\
 polyominoes\
 puzzle\
+pyraminx\
 pyro\
 pyro2\
 qix\
