@@ -54,7 +54,7 @@ static const char sccsid[] = "@(#)rubik.c	5.01 2001/03/01 xlockmore";
  *              movement and three consecutive identical moves (which is
  *              pretty stupid).
  *              improved the "cycles" option in replacement of David's hack,
- *              now rp->anglestep is a GLfloat, so this option selects the
+ *              now rp->angleStep is a GLfloat, so this option selects the
  *              "exact" number of frames that a rotation (movement) takes to
  *              complete.
  * 30-Jul-1997: Initial release, there is no algorithm to solve the puzzle,
@@ -375,10 +375,9 @@ typedef struct {
 	int         degreeTurn;
 	int         shufflingmoves;
 	int         sizex, sizey, sizez;
-	float       avsize, avsizeSq;
 	int         action;
 	int         done;
-	GLfloat     anglestep;
+	GLfloat     angleStep;
 	RubikLoc   *cubeLoc[MAX_FACES];
 	RubikLoc   *rowLoc[MAX_ORIENT];
 	RubikMove   movement;
@@ -444,46 +443,46 @@ static rubikstruct *rubik = (rubikstruct *) NULL;
 
 
 static void
-pickcolor(int C, int mono)
+pickColor(int c, int mono)
 {
-	switch (C) {
-		case TOP_FACE:
-			if (mono)
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray3);
-			else
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialRed);
-			break;
-		case LEFT_FACE:
-			if (mono)
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray6);
-			else
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialYellow);
-			break;
-		case FRONT_FACE:
-			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialWhite);
-			break;
-		case RIGHT_FACE:
-			if (mono)
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray4);
-			else
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGreen);
-			break;
-		case BOTTOM_FACE:
-			if (mono)
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray7);
-			else
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialOrange);
-			break;
-		case BACK_FACE:
-			if (mono)
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray5);
-			else
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialBlue);
-			break;
+	switch (c) {
+	case TOP_FACE:
+		if (mono)
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray3);
+		else
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialRed);
+		break;
+	case LEFT_FACE:
+		if (mono)
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray6);
+		else
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialYellow);
+		break;
+	case FRONT_FACE:
+		glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialWhite);
+		break;
+	case RIGHT_FACE:
+		if (mono)
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray4);
+		else
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGreen);
+		break;
+	case BOTTOM_FACE:
+		if (mono)
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray7);
+		else
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialOrange);
+		break;
+	case BACK_FACE:
+		if (mono)
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray5);
+		else
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialBlue);
+		break;
 #if 0
-		default:
-			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialCyan);
-			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialMagenta);
+	default:
+		glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialCyan);
+		glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialMagenta);
 #endif
 	}
 }
@@ -699,7 +698,7 @@ draw_cubit(ModeInfo * mi,
 		return False;
 	if (back != NO_FACE) {
 		glBegin(GL_POLYGON);
-		pickcolor(back, mono);
+		pickColor(back, mono);
 		glNormal3f(0.00, 0.00, -1.00);
 		glVertex3f(-STICKER_SHORT, STICKER_LONG, -STICKER_DEPTH);
 		glVertex3f(STICKER_SHORT, STICKER_LONG, -STICKER_DEPTH);
@@ -713,7 +712,7 @@ draw_cubit(ModeInfo * mi,
 	}
 	if (front != NO_FACE) {
 		glBegin(GL_POLYGON);
-		pickcolor(front, mono);
+		pickColor(front, mono);
 		glNormal3f(0.00, 0.00, 1.00);
 		glVertex3f(-STICKER_SHORT, -STICKER_LONG, STICKER_DEPTH);
 		glVertex3f(STICKER_SHORT, -STICKER_LONG, STICKER_DEPTH);
@@ -727,7 +726,7 @@ draw_cubit(ModeInfo * mi,
 	}
 	if (left != NO_FACE) {
 		glBegin(GL_POLYGON);
-		pickcolor(left, mono);
+		pickColor(left, mono);
 		glNormal3f(-1.00, 0.00, 0.00);
 		glVertex3f(-STICKER_DEPTH, -STICKER_SHORT, STICKER_LONG);
 		glVertex3f(-STICKER_DEPTH, STICKER_SHORT, STICKER_LONG);
@@ -741,7 +740,7 @@ draw_cubit(ModeInfo * mi,
 	}
 	if (right != NO_FACE) {
 		glBegin(GL_POLYGON);
-		pickcolor(right, mono);
+		pickColor(right, mono);
 		glNormal3f(1.00, 0.00, 0.00);
 		glVertex3f(STICKER_DEPTH, -STICKER_SHORT, -STICKER_LONG);
 		glVertex3f(STICKER_DEPTH, STICKER_SHORT, -STICKER_LONG);
@@ -755,7 +754,7 @@ draw_cubit(ModeInfo * mi,
 	}
 	if (bottom != NO_FACE) {
 		glBegin(GL_POLYGON);
-		pickcolor(bottom, mono);
+		pickColor(bottom, mono);
 		glNormal3f(0.00, -1.00, 0.00);
 		glVertex3f(STICKER_LONG, -STICKER_DEPTH, -STICKER_SHORT);
 		glVertex3f(STICKER_LONG, -STICKER_DEPTH, STICKER_SHORT);
@@ -769,7 +768,7 @@ draw_cubit(ModeInfo * mi,
 	}
 	if (top != NO_FACE) {
 		glBegin(GL_POLYGON);
-		pickcolor(top, mono);
+		pickColor(top, mono);
 		glNormal3f(0.00, 1.00, 0.00);
 		glVertex3f(-STICKER_LONG, STICKER_DEPTH, -STICKER_SHORT);
 		glVertex3f(-STICKER_LONG, STICKER_DEPTH, STICKER_SHORT);
@@ -851,7 +850,7 @@ draw_cube(ModeInfo * mi)
  * The glRotatef() routine transforms the coordinate system for every future
  * vertex specification (this is not so simple, but by now comprehending this
  * is sufficient). So if you want to rotate the inner slice, you can draw
- * one slice, rotate the anglestep for the centerslice, draw the inner slice,
+ * one slice, rotate the angleStep for the centerslice, draw the inner slice,
  * rotate reversely and draw the other slice.
  * There is a sequence for drawing cubies for each axis being moved...
  */
@@ -1826,15 +1825,15 @@ evalmovement(ModeInfo * mi, RubikMove movement)
 }
 
 static      Bool
-compare_moves(rubikstruct * rp, RubikMove move1, RubikMove move2, Bool opp)
+compareMoves(rubikstruct * rp, RubikMove move1, RubikMove move2, Bool opp)
 {
-	RubikSlice  slice1, slice2;
+	RubikSlice slice1, slice2;
 
 	convertMove(rp, move1, &slice1);
 	convertMove(rp, move2, &slice2);
 	if (slice1.face == slice2.face &&
 	    slice1.depth == slice2.depth) {
-		if (slice1.rotation == slice2.rotation) {	/* CW or CCW */
+		if (slice1.rotation == slice2.rotation) { /* CW or CCW */
 			if (!opp)
 				return True;
 		} else {
@@ -1858,9 +1857,8 @@ shuffle(ModeInfo * mi)
 		i = MI_SIZE(mi);
 	if (i < -MINSIZE)
 		i = NRAND(-i - MINSIZE + 1) + MINSIZE;
-	else if (i < MINSIZE)
+	else if (i < MINSIZE - 1)
 		i = MINSIZE;
-
 	if (LRAND() % 2 && !sizey && !sizez) { /* Make normal (NxNxN) cubes more likely */
 		MAXSIZEX = MAXSIZEY = MAXSIZEZ = i;
 	} else {
@@ -1873,7 +1871,7 @@ shuffle(ModeInfo * mi)
 			i = NRAND(-i - MINSIZE + 1) + MINSIZE;
 		else if (i < MINSIZE)
 			i = MINSIZE;
-		if (LRAND() % 2 && !sizez) { /* Make more MxNxN more likely than LxMxN */
+		if (LRAND() % 2 && !sizez) { /* Make MxNxN more likely than LxMxN */
 			MAXSIZEY = MAXSIZEZ = i;
 		} else {
 			MAXSIZEY = i;
@@ -1928,9 +1926,9 @@ shuffle(ModeInfo * mi)
 			return False;
 		}
 	if (MI_CYCLES(mi) <= 1) {
-		rp->anglestep = 90.0;
+		rp->angleStep = 90.0;
 	} else {
-		rp->anglestep = 90.0 / (GLfloat) (MI_CYCLES(mi));
+		rp->angleStep = 90.0 / (GLfloat) (MI_CYCLES(mi));
 	}
 
 	for (i = 0; i < rp->storedmoves; i++) {
@@ -1944,15 +1942,15 @@ shuffle(ModeInfo * mi)
 				rowToRotate[move.face][move.direction])) ? 90 : 180;
 			condition = True;
 			if (i > 0) {	/* avoid immediate undoing moves */
-				if (compare_moves(rp, move, rp->moves[i - 1], True))
+				if (compareMoves(rp, move, rp->moves[i - 1], True))
 					condition = False;
 				if (rp->degreeTurn == 180 &&
-				    compare_moves(rp, move, rp->moves[i - 1], False))
+				    compareMoves(rp, move, rp->moves[i - 1], False))
 					condition = False;
 			}
 			if (i > 1)	/* avoid 3 consecutive identical moves */
-				if (compare_moves(rp, move, rp->moves[i - 1], False) &&
-				    compare_moves(rp, move, rp->moves[i - 2], False))
+				if (compareMoves(rp, move, rp->moves[i - 1], False) &&
+				    compareMoves(rp, move, rp->moves[i - 2], False))
 					condition = False;
 			/*
 			 * Still some silly moves being made....
@@ -2238,7 +2236,7 @@ draw_rubik(ModeInfo * mi)
 					else
 						rp->degreeTurn = (checkFaceSquare(rp, rowToRotate[rp->movement.face][rp->movement.direction])) ? 90 : 180;
 				}
-				rp->rotateStep += rp->anglestep;
+				rp->rotateStep += rp->angleStep;
 				if (rp->rotateStep > rp->degreeTurn) {
 					if (!evalmovement(mi, rp->movement)) {
 						free_rubik_screen(rp);
@@ -2282,7 +2280,7 @@ draw_rubik(ModeInfo * mi)
 					else
 						rp->degreeTurn = (checkFaceSquare(rp, rowToRotate[rp->movement.face][rp->movement.direction])) ? 90 : 180;
 				}
-				rp->rotateStep += rp->anglestep;
+				rp->rotateStep += rp->angleStep;
 				if (rp->rotateStep > rp->degreeTurn) {
 					if (!evalmovement(mi, rp->movement)) {
 						free_rubik_screen(rp);
