@@ -167,7 +167,7 @@ ModStruct   skewb_description =
 #define BOTTOM 10
 #define LEFT 11
 #define MAX_ROTATE 3
-#define MAXCUBES (MAX_ORIENT+1)
+#define MAX_CUBES (MAX_ORIENT+1)
 #define MINOR 0
 #define MAJOR 1
 #define MAX_FACES 6
@@ -402,9 +402,9 @@ typedef struct {
 	int         shufflingmoves;
 	int         action;
 	int         done;
-	GLfloat     anglestep;
-	SkewbLoc    cubeLoc[MAX_FACES][MAXCUBES];
-	SkewbLoc    rowLoc[MAX_ORIENT][MAXCUBES];
+	GLfloat     angleStep;
+	SkewbLoc    cubeLoc[MAX_FACES][MAX_CUBES];
+	SkewbLoc    rowLoc[MAX_ORIENT][MAX_CUBES];
 	SkewbLoc    minorLoc[MAX_ORIENT], majorLoc[MAX_ORIENT][MAX_ORIENT];
 	SkewbMove   movement;
 	GLfloat     rotateStep;
@@ -462,42 +462,42 @@ static float MaterialGray7[] =
 static skewbstruct *skewb = (skewbstruct *) NULL;
 
 static void
-pickColor(int C, int mono)
+pickColor(int c, int mono)
 {
-	switch (C) {
-		case TOP_FACE:
-			if (mono)
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray3);
-			else
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialRed);
-			break;
-		case LEFT_FACE:
-			if (mono)
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray5);
-			else
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialBlue);
-			break;
-		case FRONT_FACE:
-			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialWhite);
-			break;
-		case RIGHT_FACE:
-			if (mono)
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray4);
-			else
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGreen);
-			break;
-		case BOTTOM_FACE:
-			if (mono)
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray7);
-			else
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialPink);
-			break;
-		case BACK_FACE:
-			if (mono)
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray6);
-			else
-				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialYellow);
-			break;
+	switch (c) {
+	case TOP_FACE:
+		if (mono)
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray3);
+		else
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialRed);
+		break;
+	case LEFT_FACE:
+		if (mono)
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray5);
+		else
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialBlue);
+		break;
+	case FRONT_FACE:
+		glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialWhite);
+		break;
+	case RIGHT_FACE:
+		if (mono)
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray4);
+		else
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGreen);
+		break;
+	case BOTTOM_FACE:
+		if (mono)
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray7);
+		else
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialPink);
+		break;
+	case BACK_FACE:
+		if (mono)
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray6);
+		else
+			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialYellow);
+		break;
 	}
 }
 
@@ -1019,6 +1019,9 @@ static int nextCorner[MAX_FACES][MAX_ORIENT] =
 	{5, 7, 3, 1}
 };
 
+static int oppCorner[8] = 
+{7, 6, 5, 4, 3, 2, 1, 0};
+
 #if 0
 static int nextFace[MAX_FACES][MAX_ORIENT] =
 {
@@ -1047,8 +1050,8 @@ convertMove(SkewbMove move, SkewbSlice * slice)
 }
 
 /*-
- * If you want to rotate a slice, you can draw that at the anglestep,
-  then the without anglestep.
+ * If you want to rotate a slice, you can draw that at the angleStep,
+  then the without angleStep.
  * There is a sequence for drawing cubies for each axis being moved...
  */
 static void
@@ -1104,7 +1107,7 @@ drawCube(ModeInfo * mi)
 static void
 rotateFace(skewbstruct * sp, int face, int direction)
 {
-	SkewbLoc faceLoc[MAXCUBES];
+	SkewbLoc faceLoc[MAX_CUBES];
 	int corner;
 
 	/* Read Face */
@@ -1131,7 +1134,7 @@ readFace(skewbstruct * sp, int face, int h)
 {
 	int position;
 
-	for (position = 0; position < MAXCUBES; position++)
+	for (position = 0; position < MAX_CUBES; position++)
 		sp->rowLoc[h][position] = sp->cubeLoc[face][position];
 }
 
@@ -1287,7 +1290,7 @@ printCube(skewbstruct * sp)
 	int	 face, position;
 
 	for (face = 0; face < MAX_FACES; face++) {
-		for (position = 0; position < MAXCUBES; position++) {
+		for (position = 0; position < MAX_CUBES; position++) {
 			(void) printf("%d %d  ", sp->cubeLoc[face][position].face,
 			sp->cubeLoc[face][position].rotation);
 		}
@@ -1313,28 +1316,16 @@ evalmovement(ModeInfo * mi, SkewbMove movement)
 
 }
 
-#ifdef HACK
-static      Bool
-compare_moves(skewbstruct * sp, SkewbMove move1, SkewbMove move2, Bool opp)
+static Bool
+compareMoves(SkewbMove move1, SkewbMove move2)
 {
-#ifdef FIXME
-	SkewbLoc  slice1, slice2;
+	SkewbSlice slice1, slice2;
 
-	convertMove(sp, move1, &slice1);
-	convertMove(sp, move2, &slice2);
-	if (slice1.face == slice2.face) {
-		if (slice1.rotation == slice2.rotation) { /* CW or CCW */
-			if (!opp)
-				return True;
-		} else {
-			if (opp)
-				return True;
-		}
-	}
-#endif
-	return False;
+	convertMove(move1, &slice1);
+	convertMove(move2, &slice2);
+	return (slice1.corner == slice2.corner
+		|| slice1.corner == oppCorner[slice2.corner]);
 }
-#endif
 
 static Bool
 shuffle(ModeInfo * mi)
@@ -1344,7 +1335,7 @@ shuffle(ModeInfo * mi)
 	SkewbMove   move;
 
 	for (face = 0; face < MAX_FACES; face++) {
-		for (position = 0; position < MAXCUBES; position++) {
+		for (position = 0; position < MAX_CUBES; position++) {
 			sp->cubeLoc[face][position].face = face;
 			sp->cubeLoc[face][position].rotation = TOP;
 		}
@@ -1362,9 +1353,9 @@ shuffle(ModeInfo * mi)
 			return False;
 		}
 	if (MI_CYCLES(mi) <= 1) {
-		sp->anglestep = 120.0;
+		sp->angleStep = 120.0;
 	} else {
-		sp->anglestep = 120.0 / (GLfloat) (MI_CYCLES(mi));
+		sp->angleStep = 120.0 / (GLfloat) (MI_CYCLES(mi));
 	}
 
 	for (i = 0; i < sp->storedmoves; i++) {
@@ -1376,9 +1367,9 @@ shuffle(ModeInfo * mi)
 			move.direction = ((move.position +
 				((NRAND(2) == 0) ? 1 : 3)) % MAX_ORIENT);
 			condition = True;
-			/*
-			 * Some silly moves being made, weed out later....
-			 */
+			if (i > 0 && compareMoves(move, sp->moves[i - 1])) {
+				condition = False;
+			}
 		} while (!condition);
 		if (hideshuffling)
 			evalmovement(mi, move);
@@ -1638,7 +1629,7 @@ draw_skewb(ModeInfo * mi)
 				if (sp->rotateStep == 0) {
 					;
 				}
-				sp->rotateStep += sp->anglestep;
+				sp->rotateStep += sp->angleStep;
 				if (sp->rotateStep > 120) {
 					evalmovement(mi, sp->movement);
 					sp->shufflingmoves++;
@@ -1671,7 +1662,7 @@ draw_skewb(ModeInfo * mi)
 				if (sp->rotateStep == 0) {
 					;
 				}
-				sp->rotateStep += sp->anglestep;
+				sp->rotateStep += sp->angleStep;
 				if (sp->rotateStep > 120) {
 					evalmovement(mi, sp->movement);
 					sp->storedmoves--;
