@@ -143,6 +143,9 @@ static char gl_modes[][MAXMODECHARS] =
 #ifdef MODE_atunnels
 	"atunnels",
 #endif
+#ifdef MODE_bevel
+	"bevel",
+#endif
 #ifdef MODE_boxed
 	"boxed",
 #endif
@@ -152,6 +155,9 @@ static char gl_modes[][MAXMODECHARS] =
 #ifdef MODE_cage
 	"cage",
 #endif
+#ifdef MODE_dino
+	"dino",
+#endif
 #ifdef MODE_fire
 	"fire",
 #endif
@@ -173,6 +179,9 @@ static char gl_modes[][MAXMODECHARS] =
 #ifdef MODE_maze3d
 	"maze3d",
 #endif
+#ifdef MODE_mball
+	"mball",
+#endif
 #ifdef MODE_moebius
 	"moebius",
 #endif
@@ -185,9 +194,15 @@ static char gl_modes[][MAXMODECHARS] =
 #ifdef MODE_noof
 	"noof",
 #endif
+#ifdef MODE_oct
+	"oct",
+#endif
 #ifdef MODE_pipes
 	"pipes",
 #endif
+#ifdef MODE_pyraminx
+	"pyraminx",
+#endif
 #ifdef MODE_rubik
 	"rubik",
 #endif
@@ -944,8 +959,12 @@ parsemodelist(ModeInfo * mi)
 	if (MI_IS_DEBUG(mi)) {
 		(void) fprintf(stderr, "%d mode%s: ", nmodes, ((nmodes == 1) ? "" : "s"));
 		for (i = 0; i < nmodes; i++)
-			(void) fprintf(stderr, "%s, ",
-				LockProcs[i].cmdline_arg);
+			if (i == nmodes - 1)
+				(void) fprintf(stderr, "%s",
+					LockProcs[modes[i]].cmdline_arg);
+			else
+				(void) fprintf(stderr, "%s, ",
+					LockProcs[modes[i]].cmdline_arg);
 		(void) fprintf(stderr, "\n");
 	}
 	return True;
