@@ -84,6 +84,12 @@ LockStruct  LockProcs[] =
 	 100000, -8, 1, 0, 64, 1.0, (char *) "",
 	 (char *) "Shows bouncing flying bats", 0, NULL},
 #endif
+#ifdef MODE_bevel
+	{(char *) "bevel", init_bevel, draw_bevel, release_bevel,
+	 draw_bevel, change_bevel, (ModeHook *) NULL, &bevel_opts,
+	 100000, -30, 5, 1, 64, 1.0, (char *) "",
+	 (char *) "Shows an auto-solving Bevel or Helicopter Cube", 0, NULL},
+#endif
 #ifdef MODE_billiards
 	{(char *) "billiards", init_billiards, draw_billiards, release_billiards,
 	 refresh_billiards, init_billiards, (ModeHook *) NULL, &billiards_opts,
@@ -210,6 +216,12 @@ LockStruct  LockProcs[] =
 	 200000, -2, 1000, 0, 64, 1.0, (char *) "",
 	 (char *) "Shows Lloyd's Prisoner's Dilemma simulation", 0, NULL},
 #endif
+#ifdef MODE_dino
+	{(char *) "dino", init_dino, draw_dino, release_dino,
+	 draw_dino, change_dino, (ModeHook *) NULL, &dino_opts,
+	 100000, -30, 5, 1, 64, 1.0, (char *) "",
+	 (char *) "Shows an auto-solving Dinosaur Cube", 0, NULL},
+#endif
 #ifdef MODE_discrete
 	{(char *) "discrete", init_discrete, draw_discrete, release_discrete,
 	 refresh_discrete, init_discrete, (ModeHook *) NULL, &discrete_opts,
@@ -385,7 +397,7 @@ LockStruct  LockProcs[] =
 	 (char *) "Shows a kaleidoscope", 0, NULL},
 #endif
 #ifdef MODE_kaleid2
- 	{"kaleid2", init_kaleid2, draw_kaleid2, release_kaleid2,
+	{"kaleid2", init_kaleid2, draw_kaleid2, release_kaleid2,
 	 refresh_kaleid2, init_kaleid2, NULL, &kaleid2_opts,
 	 20000, 1, 700, 1, 64, 1.0, "",
 	 (char *) "Shows a kaleidoscope", 0, NULL},
@@ -486,6 +498,12 @@ LockStruct  LockProcs[] =
 	 20000, 1, 2, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows a 3D maze", 0, NULL},
 #endif
+#ifdef MODE_mball
+	{(char *) "mball", init_mball, draw_mball, release_mball,
+	 draw_mball, change_mball, (ModeHook *) NULL, &mball_opts,
+	 100000, -30, 5, -6, 64, 1.0, (char *) "",
+	 (char *) "Shows an auto-solving Masterball puzzle", 0, NULL},
+#endif
 #ifdef MODE_moebius
 	{(char *) "moebius", init_moebius, draw_moebius, release_moebius,
 	 draw_moebius, change_moebius, (ModeHook *) NULL, &moebius_opts,
@@ -528,6 +546,12 @@ LockStruct  LockProcs[] =
 	 100000, 1, 1, 1, 64, 1.0, (char *) "",
     (char *) "Shows a man with a big nose runs around spewing out messages", 0, NULL},
 #endif
+#ifdef MODE_oct
+	{(char *) "oct", init_oct, draw_oct, release_oct,
+	 draw_oct, change_oct, (ModeHook *) NULL, &oct_opts,
+	 100000, -30, 5, -5, 64, 1.0, (char *) "",
+	 (char *) "Shows an auto-solving octahedron puzzle", 0, NULL},
+#endif
 #ifdef MODE_pacman
 	{(char *) "pacman", init_pacman, draw_pacman, release_pacman,
 	 refresh_pacman, change_pacman, (ModeHook *) NULL, &pacman_opts,
@@ -575,6 +599,12 @@ LockStruct  LockProcs[] =
 	 10000, 250, 1, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows a puzzle being scrambled and then solved", 0, NULL},
 #endif
+#ifdef MODE_pyraminx
+	{(char *) "pyraminx", init_pyraminx, draw_pyraminx, release_pyraminx,
+	 draw_pyraminx, change_pyraminx, (ModeHook *) NULL, &pyraminx_opts,
+	 100000, -30, 5, -5, 64, 1.0, (char *) "",
+	 (char *) "Shows an auto-solving Pyraminx puzzle", 0, NULL},
+#endif
 #ifdef MODE_pyro
 	{(char *) "pyro", init_pyro, draw_pyro, release_pyro,
 	 refresh_pyro, init_pyro, (ModeHook *) NULL, &pyro_opts,
