@@ -20,6 +20,9 @@ static LockStruct LockProcs[] =
 #endif
 {(char *) "ball", (char *) "Shows bouncing balls"},
 {(char *) "bat", (char *) "Shows bouncing flying bats"},
+#ifdef USE_GL
+{(char *) "bevel", (char *) "Shows an auto-solving Bevel or Helicopter Cube"},
+#endif
 {(char *) "blot", (char *) "Shows Rorschach's ink blot test"},
 {(char *) "bouboule", (char *) "Shows Mimi's bouboule of moving stars"},
 {(char *) "bounce", (char *) "Shows bouncing footballs"},
@@ -44,6 +47,9 @@ static LockStruct LockProcs[] =
 {(char *) "deco", (char *) "Shows art as ugly as sin"},
 {(char *) "demon", (char *) "Shows Griffeath's cellular automata"},
 {(char *) "dilemma", (char *) "Shows Lloyd's Prisoner's Dilemma simulation"},
+#ifdef USE_GL
+{(char *) "dino", (char *) "Shows an auto-solving Dinosaur Cube"},
+#endif
 {(char *) "discrete", (char *) "Shows various discrete maps"},
 {(char *) "dragon", (char *) "Shows Deventer's Hexagonal Dragons Maze"},
 {(char *) "drift", (char *) "Shows cosmic drifting flame fractals"},
@@ -107,6 +113,9 @@ static LockStruct LockProcs[] =
 {(char *) "moebius", (char *) "Shows Moebius Strip II, an Escher-like GL scene with ants"},
 #endif
 #ifdef USE_GL
+{(char *) "mball", (char *) "Shows an auto-solving Masterball puzzle"},
+#endif
+#ifdef USE_GL
 {(char *) "molecule", (char *) "Draws molecules"},
 #endif
 #ifdef USE_GL
@@ -118,6 +127,9 @@ static LockStruct LockProcs[] =
 {(char *) "noof", (char *) "Shows SGI Diatoms"},
 #endif
 {(char *) "nose", (char *) "Shows a man with a big nose runs around spewing out messages"},
+#ifdef USE_GL
+{(char *) "oct", (char *) "Shows an auto-solving octahedron puzzle"},
+#endif
 {(char *) "pacman", (char *) "Shows Pacman(tm)"},
 {(char *) "penrose", (char *) "Shows Penrose's quasiperiodic tilings"},
 {(char *) "petal", (char *) "Shows various GCD Flowers"},
@@ -127,6 +139,9 @@ static LockStruct LockProcs[] =
 #endif
 {(char *) "polyominoes", (char *) "Shows attempts to place polyominoes into a rectangle"},
 {(char *) "puzzle", (char *) "Shows a puzzle being scrambled and then solved"},
+#ifdef USE_GL
+{(char *) "pyraminx", (char *) "Shows an auto-solving Pyraminx puzzle"},
+#endif
 {(char *) "pyro", (char *) "Shows fireworks"},
 {(char *) "pyro2", (char *) "Shows other fireworks"},
 {(char *) "qix", (char *) "Shows spinning lines a la Qix(tm)"},
